@@ -1,4 +1,3 @@
-#!/usr/bin/python3
 # SPDX-License-Identifier: MIT
 
 """
@@ -58,6 +57,7 @@ from amd_debug.failures import (
     MissingAmdgpu,
     MissingAmdgpuFirmware,
     MissingAmdPmc,
+    MissingGpu,
     MissingDriver,
     MissingIommuACPI,
     MissingIommuPolicy,
@@ -156,7 +156,7 @@ class PrerequisiteValidator(AmdTool):
         if len(edids) == 0:
             self.db.record_debug("No EDID data found")
             return True
-        for name, p in edids.items():
+        for p in edids:
             output = None
             for tool in ["di-edid-decode", "edid-decode"]:
                 try:
@@ -167,16 +167,17 @@ class PrerequisiteValidator(AmdTool):
                     break
                 except FileNotFoundError:
                     self.db.record_debug(f"{cmd} not installed")
-                except subprocess.CalledProcessError as e:
+                except subprocess.CalledProcessError as _e:
                     pass
             if not output:
                 self.db.record_prereq("Failed to capture EDID table", "👀")
             else:
-                self.db.record_debug(apply_prefix_wrapper(f"EDID for {name}:", output))
+                self.db.record_debug(apply_prefix_wrapper(f"EDID for {p}:", output))
         return True
 
     def check_amdgpu(self):
         """Check for the AMDGPU driver"""
+        count = 0
         for device in self.pyudev.list_devices(subsystem="pci"):
             klass = device.properties.get("PCI_CLASS")
             if klass not in ["30000", "38000"]:
@@ -184,6 +185,7 @@ class PrerequisiteValidator(AmdTool):
             pci_id = device.properties.get("PCI_ID")
             if not pci_id.startswith("1002"):
                 continue
+            count += 1
             if device.properties.get("DRIVER") != "amdgpu":
                 self.db.record_prereq("GPU driver `amdgpu` not loaded", "❌")
                 self.failures += [MissingAmdgpu()]
@@ -191,6 +193,10 @@ class PrerequisiteValidator(AmdTool):
             slot = device.properties.get("PCI_SLOT_NAME")
 
             self.db.record_prereq(f"GPU driver `amdgpu` bound to {slot}", "✅")
+        if count == 0:
+            self.db.record_prereq("Integrated GPU not found", "❌")
+            self.failures += [MissingGpu()]
+            return False
         return True
 
     def check_amdgpu_parameters(self):
@@ -742,6 +748,9 @@ class PrerequisiteValidator(AmdTool):
             p = os.path.join("/", "sys", "kernel", "debug", "gpio")
             try:
                 contents = read_file(p)
+            except FileNotFoundError:
+                self.db.record_prereq("GPIO debugfs not available", "👀")
+                contents = None
             except PermissionError:
                 self.db.record_debug(f"Unable to capture {p}")
                 contents = None
@@ -778,7 +787,7 @@ class PrerequisiteValidator(AmdTool):
                     "utf-8"
                 )
             except FileNotFoundError:
-                self.db.record_prereq(f"ethtool is missing", "👀")
+                self.db.record_prereq("ethtool is missing", "👀")
                 return True
             for line in output.split("\n"):
                 if "Supports Wake-on" in line:
@@ -1179,7 +1188,6 @@ class PrerequisiteValidator(AmdTool):
         if self.cpu_family == 0x1A and self.cpu_model in affected_1a:
             found_iommu = False
             found_acpi = False
-            found_dmar = False
             for dev in self.pyudev.list_devices(subsystem="iommu"):
                 found_iommu = True
                 debug_str += f"Found IOMMU {dev.sys_path}\n"
@@ -1355,7 +1363,7 @@ class PrerequisiteValidator(AmdTool):
                     logging.debug(line)
 
         if len(self.failures) == 0:
-            return True
+            return
         print_color(Headers.ExplanationReport, "🗣️")
         for item in self.failures:
             item.get_failure()
